.. include:: ../../README.rst

Python API
----------

The main entry point to the API is :py:class:`metalsmith.Provisioner`.

.. toctree::
   :maxdepth: 3

   reference/api/metalsmith

.. toctree::
   :hidden:

   reference/api/modules

Command-Line Interface
----------------------

.. toctree::
   :maxdepth: 2

   cli/index

Ansible Role
------------

.. toctree::
   :maxdepth: 2

   user/ansible

Indexes
-------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
